.. _api:

API Reference
=============

In this section you will find a detailed specification of all the public functions
and classes in SDV.

.. toctree::
   :maxdepth: 2

   sdv
   lite/index
   tabular/index
   relational/index
   timeseries/index
   metadata/index
   constraints/index
   sampling/index
   metrics/index
   evaluation
   demo
